@@ -49,10 +49,6 @@ fetch_uniprot <-
            ),
            batchsize = 200,
            show_progress = TRUE) {
-    if (!requireNamespace("httr", quietly = TRUE)) {
-      stop("Package \"httr\" is needed for this function to work. Please install it.", call. = FALSE)
-    }
-
     if (!curl::has_internet()) {
       message("No internet connection.")
       return(invisible(NULL))
